package com.fzm.admin.controller;

import com.fzm.common.annotation.Authentication;
import com.fzm.common.entity.Banner;
import com.fzm.common.model.ResponseModel;
import com.fzm.common.service.BannerService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author tangtuo
 * @date 2022/1/11 14:35
 */
@Authentication
@RestController
@RequestMapping("/banner")
@Api(tags = "banner页管理")
public class BannerController {

    @Resource
    private BannerService bannerService;

    @PostMapping("/create")
    @ApiOperation("新建banner")
    public ResponseModel<Boolean> create(@Validated @RequestBody Banner banner) {
        return ResponseModel.success(bannerService.save(banner));
    }

    @GetMapping("/page")
    @ApiOperation("分页查询banner列表")
    public ResponseModel<PageInfo<Banner>> page() {
        List<Banner> list = bannerService.listAll();
        return ResponseModel.success(new PageInfo<>(list));
    }

    @GetMapping("/detail")
    @ApiOperation("查询banner详情")
    public ResponseModel<Banner> getDetailById(@RequestParam Integer id) {
        return ResponseModel.success(bannerService.getById(id));
    }

    @PostMapping("/update")
    @ApiOperation("修改banner")
    public ResponseModel<Boolean> update(@RequestBody Banner banner) {
        return ResponseModel.success(bannerService.updateById(banner));
    }

    @PostMapping("/delete")
    @ApiOperation("删除banner")
    public ResponseModel<Boolean> delete(@RequestParam Integer id) {
        return ResponseModel.success(bannerService.removeById(id));
    }
}
